Module weeb_api::bridge::reqwest
[−]
[src]
Bridge to provide a client implementation for the reqwest crate.
Examples
Refer to the documentation for WeebApiRequester.
Traits
| WeebApiRequester |
Trait which defines the methods necessary to interact with the service. |