Module weeb_api::constants
[−]
[src]
A set of constants used for the various requests in the library.
Constants
| BASE_API_URI |
The base API url. |
| BASE_CDN_URI |
The base CDN url. |
| GET_IMAGES |
Url used to get basic info about the API. |
| GET_IMAGE_INFO |
Url used to get information about an image. |
| GET_IMAGE_RANDOM |
Url used to get a random image. |
| GET_IMAGE_TAGS |
Url used to get all the image tags. |
| GET_IMAGE_TYPES |
Url used to get all the image types. |
| POST_IMAGE |
Url used to post an image to the Api. |